@@ -1,5 +1,5 @@
-from flask import Blueprint, render_template, url_for, redirect, flash, current_app, request
-from flask_babel import gettext as _, lazy_gettext
+from flask import Blueprint, render_template, current_app, request
+from flask_babel import lazy_gettext
 
 from uffd.navbar import register_navbar
 from uffd.session import login_required
@@ -7,16 +7,15 @@ from uffd.session import login_required
 from .models import Group
 
 bp = Blueprint("group", __name__, template_folder='templates', url_prefix='/group/')
-@bp.before_request
-@login_required()
-def group_acl(): #pylint: disable=inconsistent-return-statements
-	if not group_acl_check():
-		flash(_('Access denied'))
-		return redirect(url_for('index'))
 
 def group_acl_check():
 	return request.user and request.user.is_in_group(current_app.config['ACL_ADMIN_GROUP'])
 
+@bp.before_request
+@login_required(group_acl_check)
+def group_acl():
+	pass
+
 @bp.route("/")
 @register_navbar(23, lazy_gettext('Groups'), icon='layer-group', blueprint=bp, visible=group_acl_check)
 def index():
