@@ -15,16 +15,17 @@ from uffd.ldap import ldap, LDAPCommitError
 from .models import User
 
 bp = Blueprint("user", __name__, template_folder='templates', url_prefix='/user/')
-@bp.before_request
-@login_required()
-def user_acl(): #pylint: disable=inconsistent-return-statements
-	if not user_acl_check():
-		flash(_('Access denied'))
-		return redirect(url_for('index'))
+
+bp.add_app_template_global(User, 'User')
 
 def user_acl_check():
 	return request.user and request.user.is_in_group(current_app.config['ACL_ADMIN_GROUP'])
 
+@bp.before_request
+@login_required(user_acl_check)
+def user_acl():
+	pass
+
 @bp.route("/")
 @register_navbar(21, lazy_gettext('Users'), icon='users', blueprint=bp, visible=user_acl_check)
 def index():
